@@ -1,21 +1,20 @@
 import random
-from ezcode.array.utils import swap
 
 
 def partition_with_first_item_as_pivot(array: list, begin: int, end: int, reverse: bool = False):
     pivot, b = begin, begin + 1  # b point to the item larger than or equals to array[pivot].
     for e in range(begin + 1, end + 1):
         if (not reverse and array[e] <= array[pivot]) or (reverse and array[pivot] <= array[e]):
-            swap(array, b, e)
+            array[b], array[e] = array[e], array[b]  # swap(array, b, e)
             b += 1
-    swap(array, b - 1, pivot)
+    array[b - 1], array[pivot] = array[pivot], array[b - 1]  # swap(array, b - 1, pivot)
     return b - 1
 
 
 def partition(array: list, begin: int, end: int, pivot: int, reverse: bool = False):
     if pivot < begin or pivot > end:
         raise ValueError(f"pivot {pivot} out of range [{begin}, {end}]")
-    swap(array, begin, pivot)
+    array[begin], array[pivot] = array[pivot], array[begin]  # swap(array, begin, pivot)
     return partition_with_first_item_as_pivot(array, begin, end, reverse)
 
 
